==> rheolef_6.1.orig.tar.gz: rheolef-6.1/nfem/ptst/field_evaluate_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
GEODIR=$SRCDIR
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
NPROC_MAX=${NPROC_MAX-"8"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

# ------------------
# 1D
# ------------------
L="
line-20-bdry.geo
"
for geo in $L; do
  loop_mpirun "field_evaluate_tst 0.5  < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
  loop_mpirun "field_evaluate_tst 0.51 < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done
# ------------------
# 2D
# ------------------
L="
carre-10-bdry-v2.geo
carre-bamg-v2.geo
"
for geo in $L; do
  loop_mpirun "field_evaluate_tst 0.5  0.5  < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
  loop_mpirun "field_evaluate_tst 0.51 0.52 < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done
# ------------------
# 3D
# ------------------
L="
cube-5-bdry-v2.geo
cube-gmsh-v2.geo
"
for geo in $L; do
  loop_mpirun "field_evaluate_tst 0.5  0.5  0.5  < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
  loop_mpirun "field_evaluate_tst 0.51 0.52 0.53 < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done

exit $status

==> rheolef_6.7.orig.tar.gz: rheolef-6.7/nfem/ptst/field_evaluate_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
GEODIR=$SRCDIR
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
NPROC_MAX=${NPROC_MAX-"8"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

# ------------------
# 1D
# ------------------
L="
line-20-bdry.geo
"
for geo in $L; do
  loop_mpirun "./field_evaluate_tst 0.5  < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
  loop_mpirun "./field_evaluate_tst 0.51 < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done
# ------------------
# 2D
# ------------------
L="
carre-10-bdry-v2.geo
carre-bamg-v2.geo
"
for geo in $L; do
  loop_mpirun "./field_evaluate_tst 0.5  0.5  < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
  loop_mpirun "./field_evaluate_tst 0.51 0.52 < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done
# ------------------
# 3D
# ------------------
L="
cube-5-bdry-v2.geo
cube-gmsh-v2.geo
"
for geo in $L; do
  loop_mpirun "./field_evaluate_tst 0.5  0.5  0.5  < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
  loop_mpirun "./field_evaluate_tst 0.51 0.52 0.53 < $GEODIR/$geo >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done

exit $status
